@@ -40,23 +40,32 @@
     * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "drkonqi.h"
-#include "systeminformation.h"
-#include "crashedapplication.h"
-#include "drkonqibackends.h"
 
 #include <QtCore/QWeakPointer>
 #include <QtCore/QTextStream>
 #include <QtCore/QTimerEvent>
+
 #include <KMessageBox>
 #include <KFileDialog>
 #include <KTemporaryFile>
-#include <KCmdLineArgs>
 #include <KIO/NetAccess>
 #include <KCrash>
 #include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
+#include <KUrl>
+
+#include "systeminformation.h"
+#include "crashedapplication.h"
+#include "drkonqibackends.h"
 
 DrKonqi::DrKonqi()
+    : m_signal(0)
+    , m_pid(0)
+    , m_kdeinit(false)
+    , m_safer(false)
+    , m_restarted(false)
+    , m_keepRunning(false)
+    , m_thread(0)
 {
     m_backend = new KCrashBackend();
     m_systemInformation = new SystemInformation();
@@ -139,7 +148,7 @@ CrashedApplication *DrKonqi::crashedApplication()
 //static
 void DrKonqi::saveReport(const QString & reportText, QWidget *parent)
 {
-    if (KCmdLineArgs::parsedArgs()->isSet("safer")) {
+    if (isSafer()) {
         KTemporaryFile tf;
         tf.setSuffix(".kcrash.txt");
         tf.setAutoRemove(false);
@@ -148,22 +157,18 @@ void DrKonqi::saveReport(const QString & reportText, QWidget *parent)
             QTextStream textStream(&tf);
             textStream << reportText;
             textStream.flush();
-            KMessageBox::information(parent, i18nc("@info",
-                                                   "Report saved to <filename>%1</filename>.",
-                                                   tf.fileName()));
+            KMessageBox::information(parent, xi18nc("@info",
+                                                    "Report saved to <filename>%1</filename>.",
+                                                    tf.fileName()));
         } else {
             KMessageBox::sorry(parent, i18nc("@info","Could not create a file in which to save the report."));
         }
     } else {
-        QString defname = crashedApplication()->fakeExecutableBaseName() + '-'
-                            + QDateTime::currentDateTime().toString("yyyyMMdd-hhmmss") + ".kcrash.txt";
-        if (defname.contains('/')) {
-            defname = defname.mid(defname.lastIndexOf('/') + 1);
-        }
+        QString defname = getSuggestedKCrashFilename(crashedApplication());
 
-        QWeakPointer<KFileDialog> dlg = new KFileDialog(defname, QString(), parent);
+        QWeakPointer<KFileDialog> dlg = new KFileDialog(QUrl(), defname, parent);
         dlg.data()->setSelection(defname);
-        dlg.data()->setCaption(i18nc("@title:window","Select Filename"));
+        dlg.data()->setWindowTitle(i18nc("@title:window","Select Filename"));
         dlg.data()->setOperationMode(KFileDialog::Saving);
         dlg.data()->setMode(KFile::File);
         dlg.data()->setConfirmOverwrite(true);
@@ -185,8 +190,8 @@ void DrKonqi::saveReport(const QString & reportText, QWidget *parent)
                 ts << reportText;
                 ts.flush();
             } else {
-                KMessageBox::sorry(parent, i18nc("@info","Cannot open file <filename>%1</filename> "
-                                                         "for writing.", tf.fileName()));
+                KMessageBox::sorry(parent, xi18nc("@info","Cannot open file <filename>%1</filename> "
+                                                          "for writing.", tf.fileName()));
                 return;
             }
 
@@ -197,3 +202,132 @@ void DrKonqi::saveReport(const QString & reportText, QWidget *parent)
     }
 }
 
+void DrKonqi::setSignal(int signal)
+{
+    instance()->m_signal = signal;
+}
+
+void DrKonqi::setAppName(const QString &appName)
+{
+    instance()->m_appName = appName;
+}
+
+void DrKonqi::setAppPath(const QString &appPath)
+{
+    instance()->m_appPath = appPath;
+}
+
+void DrKonqi::setAppVersion(const QString &appVersion)
+{
+    instance()->m_appVersion = appVersion;
+}
+
+void DrKonqi::setBugAddress(const QString &bugAddress)
+{
+    instance()->m_bugAddress = bugAddress;
+}
+
+void DrKonqi::setProgramName(const QString &programName)
+{
+    instance()->m_programName = programName;
+}
+
+void DrKonqi::setPid(int pid)
+{
+    instance()->m_pid = pid;
+}
+
+void DrKonqi::setStartupId(const QString &startupId)
+{
+    instance()->m_startupId = startupId;
+}
+
+void DrKonqi::setKdeinit(bool kdeinit)
+{
+    instance()->m_kdeinit = kdeinit;
+}
+
+void DrKonqi::setSafer(bool safer)
+{
+    instance()->m_safer = safer;
+}
+
+void DrKonqi::setRestarted(bool restarted)
+{
+    instance()->m_restarted = restarted;
+}
+
+void DrKonqi::setKeepRunning(bool keepRunning)
+{
+    instance()->m_keepRunning = keepRunning;
+}
+
+void DrKonqi::setThread(int thread)
+{
+    instance()->m_thread = thread;
+}
+
+int DrKonqi::signal()
+{
+    return instance()->m_signal;
+}
+
+const QString &DrKonqi::appName()
+{
+    return instance()->m_appName;
+}
+
+const QString &DrKonqi::appPath()
+{
+    return instance()->m_appPath;
+}
+
+const QString &DrKonqi::appVersion()
+{
+    return instance()->m_appVersion;
+}
+
+const QString &DrKonqi::bugAddress()
+{
+    return instance()->m_bugAddress;
+}
+
+const QString &DrKonqi::programName()
+{
+    return instance()->m_programName;
+}
+
+int DrKonqi::pid()
+{
+    return instance()->m_pid;
+}
+
+const QString &DrKonqi::startupId()
+{
+    return instance()->m_startupId;
+}
+
+bool DrKonqi::isKdeinit()
+{
+    return instance()->m_kdeinit;
+}
+
+bool DrKonqi::isSafer()
+{
+    return instance()->m_safer;
+}
+
+bool DrKonqi::isRestarted()
+{
+    return instance()->m_restarted;
+}
+
+bool DrKonqi::isKeepRunning()
+{
+    return instance()->m_keepRunning;
+}
+
+int DrKonqi::thread()
+{
+    return instance()->m_thread;
+}
