@@ -35,14 +35,9 @@
 #include <QBoxLayout>
 #include <QVBoxLayout>
 #include <QTreeWidgetItemIterator>
+#include <qapplication.h>
 
-#include <KAction>
-#include <KApplication>
 #include <KConfig>
-#include <KStandardDirs>
-#include <KGlobal>
-#include <KLocale>
-#include <KDebug>
 
 #include <KLineEdit>
 #include <KMessageBox>
@@ -54,11 +49,11 @@
 #include <KServiceGroup>
 #include <KServiceTypeTrader>
 #include <KCModuleInfo>
-#include <KCModule>
 
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <QStandardPaths>
 
 #include "navigatoritem.h"
 #include "navigatorappitem.h"
@@ -80,13 +75,17 @@
 
 using namespace KHC;
 
+namespace {
+QLoggingCategory category("org.kde.khelpcenter");
+}
+
 Navigator::Navigator( View *view, QWidget *parent, const char *name )
    : QWidget( parent ), mIndexDialog( 0 ),
      mView( view ), mSelected( false )
 {
     setObjectName( name );
 
-    KConfigGroup config(KGlobal::config(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), "General");
     mShowMissingDocs = config.readEntry("ShowMissingDocs", false);
 
     mSearchEngine = new SearchEngine( view );
@@ -129,11 +128,10 @@ Navigator::Navigator( View *view, QWidget *parent, const char *name )
       hideSearch();
     } else {
       mSearchWidget->updateScopeList();
-      mSearchWidget->readConfig( KGlobal::config().data() );
+      mSearchWidget->readConfig( KSharedConfig::openConfig().data() );
     }
     */
-    connect( mTabWidget, SIGNAL( currentChanged( QWidget * ) ),
-             SLOT( slotTabChanged( QWidget * ) ) );
+    connect( mTabWidget, SIGNAL(currentChanged(int)), SLOT(slotTabChanged(int)) );
 }
 
 Navigator::~Navigator()
@@ -201,7 +199,7 @@ void Navigator::insertPlugins()
 
 void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem )
 {
-  kDebug(1400) << "Requested plugin documents for ID " << name;
+  qCDebug(category) << "Requested plugin documents for ID " << name;
 
   KServiceGroup::Ptr grp = KServiceGroup::childGroup( name );
   if ( !grp )
@@ -213,35 +211,67 @@ void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem
   for ( ; it != end; ++it ) {
     QString desktopFile = ( *it )->entryPath();
     if ( QDir::isRelativePath( desktopFile ) )
-        desktopFile = KStandardDirs::locate( "apps", desktopFile );
+        desktopFile = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, desktopFile );
     createItemFromDesktopFile( topItem, desktopFile );
   }
 }
 
 void Navigator::insertKCMDocs( const QString &name, NavigatorItem *topItem, const QString &type )
 {
-  kDebug(1400) << "Requested KCM documents for ID" << name;
+  qCDebug(category) << "Requested KCM documents for ID" << name;
+  QString systemsettingskontrolconstraint = "[X-KDE-System-Settings-Parent-Category] != ''";
+  QString konquerorcontrolconstraint = "[X-KDE-PluginKeyword] == 'khtml_general'\
+                                     or [X-KDE-PluginKeyword] == 'performance'\
+                                     or [X-KDE-PluginKeyword] == 'bookmarks'";
+  QString filemanagercontrolconstraint = "[X-KDE-PluginKeyword] == 'behavior'\
+                                       or [X-KDE-PluginKeyword] == 'dolphinviewmodes'\
+                                       or [X-KDE-PluginKeyword] == 'dolphinnavigation'\
+                                       or [X-KDE-PluginKeyword] == 'dolphinservices'\
+                                       or [X-KDE-PluginKeyword] == 'dolphingeneral'\
+                                       or [X-KDE-PluginKeyword] == 'trash'";
+  QString browsercontrolconstraint = "[X-KDE-PluginKeyword] == 'khtml_behavior'\
+                                   or [X-KDE-PluginKeyword] == 'proxy'\
+                                   or [X-KDE-PluginKeyword] == 'khtml_appearance'\
+                                   or [X-KDE-PluginKeyword] == 'khtml_filter'\
+                                   or [X-KDE-PluginKeyword] == 'cache'\
+                                   or [X-KDE-PluginKeyword] == 'cookie'\
+                                   or [X-KDE-PluginKeyword] == 'useragent'\
+                                   or [X-KDE-PluginKeyword] == 'khtml_java_js'\
+                                   or [X-KDE-PluginKeyword] == 'khtml_plugins'";
+/* missing in browsercontrolconstraint
+History                 no X-KDE-PluginKeyword in kcmhistory.desktop
+*/
+  QString othercontrolconstraint = "[X-KDE-PluginKeyword] == 'cgi'";
 
   KService::List list;
 
   if ( type == QString("kcontrol") ) {
-    list = KServiceTypeTrader::self()->query( "KCModule", "[X-KDE-ParentApp] == 'kcontrol'" );
-  } else {
+    list = KServiceTypeTrader::self()->query( "KCModule", systemsettingskontrolconstraint );
+  } else if ( type == QString("konquerorcontrol") ) {
+    list = KServiceTypeTrader::self()->query( "KCModule", konquerorcontrolconstraint );
+  } else if ( type == QString("browsercontrol") ) {
+    list = KServiceTypeTrader::self()->query( "KCModule", browsercontrolconstraint );
+  } else if ( type == QString("filemanagercontrol") ) {
+    list = KServiceTypeTrader::self()->query( "KCModule", filemanagercontrolconstraint );
+  } else if ( type == QString("othercontrol") ) {
+    list = KServiceTypeTrader::self()->query( "KCModule", othercontrolconstraint );
+  } else if ( type == QString("kinfocenter") ) {
     list = KServiceTypeTrader::self()->query( "KCModule", "[X-KDE-ParentApp] == 'kinfocenter'" );
   }
 
   for ( KService::List::const_iterator it = list.constBegin(); it != list.constEnd(); ++it )
   {
-    KService::Ptr s = (*it);
-    KCModuleInfo m = KCModuleInfo(s);
-    QString desktopFile = KStandardDirs::locate( "services", m.fileName() );
+    KService::Ptr s(*it);
+    KCModuleInfo m(s);
+    QString desktopFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kde5/services/") + m.fileName() );
     createItemFromDesktopFile( topItem, desktopFile );
     }
+    topItem->sortChildren( 0, Qt::AscendingOrder /* ascending */ );
 }
 
 void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
 {
-  kDebug(1400) << "Requested IOSlave documents for ID" << name;
+  qCDebug(category) << "Requested IOSlave documents for ID" << name;
 
   QStringList list = KProtocolInfo::protocols();
   list.sort();
@@ -253,7 +283,7 @@ void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
     if ( !docPath.isNull() )
     {
       // First parameter is ignored if second is an absolute path
-      KUrl url(KUrl("help:/"), docPath);
+      QUrl url(QStringLiteral("help:/") + docPath);
       QString icon = KProtocolInfo::icon(*it);
       if ( icon.isEmpty() ) icon = "text-plain";
       DocEntry *entry = new DocEntry( *it, url.url(), icon );
@@ -271,7 +301,7 @@ void Navigator::createItemFromDesktopFile( NavigatorItem *topItem,
     QString docPath = desktopFile.readDocPath();
     if ( !docPath.isNull() ) {
       // First parameter is ignored if second is an absolute path
-      KUrl url(KUrl("help:/"), docPath);
+      QUrl url(QStringLiteral("help:/") + docPath);
       QString icon = desktopFile.readIcon();
       if ( icon.isEmpty() ) icon = "text-plain";
       DocEntry *entry = new DocEntry( desktopFile.readName(), url.url(), icon );
@@ -293,9 +323,9 @@ NavigatorItem *Navigator::insertScrollKeeperDocs( NavigatorItem *topItem,
   return builder->build( topItem, after );
 }
 
-void Navigator::selectItem( const KUrl &url )
+void Navigator::selectItem( const QUrl &url )
 {
-  kDebug() << "Navigator::selectItem(): " << url.url();
+  qDebug() << "Navigator::selectItem(): " << url.url();
 
   if ( url.url() == "khelpcenter:home" ) {
     clearSelection();
@@ -305,20 +335,20 @@ void Navigator::selectItem( const KUrl &url )
   // help:/foo&anchor=bar gets redirected to help:/foo#bar
   // Make sure that we match both the original URL as well as
   // its counterpart.
-  KUrl alternativeURL = url;
-  if (url.hasRef())
+  QUrl alternativeURL = url;
+  if (url.hasFragment())
   {
-     alternativeURL.setQuery("anchor="+url.ref());
-     alternativeURL.setRef(QString());
+     alternativeURL.setQuery("anchor="+url.fragment());
+     alternativeURL.setFragment(QString());
   }
 
   // If the navigator already has the given URL selected, do nothing.
   NavigatorItem *item;
   item = static_cast<NavigatorItem *>( mContentsTree->currentItem() );
   if ( item && mSelected ) {
-    KUrl currentURL ( item->entry()->url() );
+    QUrl currentURL ( item->entry()->url() );
     if ( (currentURL == url) || (currentURL == alternativeURL) ) {
-      kDebug() << "URL already shown.";
+      qCDebug(category) << "URL already shown.";
       return;
     }
   }
@@ -337,7 +367,7 @@ void Navigator::selectItem( const KUrl &url )
   QTreeWidgetItemIterator it( mContentsTree );
   while ( (*it) ) {
     NavigatorItem *item = static_cast<NavigatorItem *>( (*it) );
-    KUrl itemUrl( item->entry()->url() );
+    QUrl itemUrl( item->entry()->url() );
     if ( (itemUrl == url) || (itemUrl == alternativeURL) ) {
       mContentsTree->setCurrentItem( item );
       // If the current item was not selected and remained unchanged it
@@ -369,15 +399,15 @@ void Navigator::slotItemSelected( QTreeWidgetItem *currentItem )
 
   NavigatorItem *item = static_cast<NavigatorItem *>( currentItem );
 
-  kDebug(1400) << item->entry()->name() << endl;
+  qCDebug(category) << item->entry()->name() << endl;
 
   item->setExpanded( !item->isExpanded() );
 
-  KUrl url ( item->entry()->url() );
+  QUrl url ( item->entry()->url() );
 
   
   
-  if ( url.protocol() == "khelpcenter" ) {
+  if ( url.scheme() == "khelpcenter" ) {
       mView->closeUrl();
       History::self().updateCurrentEntry( mView );
       History::self().createEntry();
@@ -390,7 +420,7 @@ void Navigator::slotItemSelected( QTreeWidgetItem *currentItem )
   mLastUrl = url;
 }
 
-void Navigator::openInternalUrl( const KUrl &url )
+void Navigator::openInternalUrl( const QUrl &url )
 {
   if ( url.url() == "khelpcenter:home" ) {
     clearSelection();
@@ -407,11 +437,11 @@ void Navigator::openInternalUrl( const KUrl &url )
   if ( item ) showOverview( item, url );
 }
 
-void Navigator::showOverview( NavigatorItem *item, const KUrl &url )
+void Navigator::showOverview( NavigatorItem *item, const QUrl &url )
 {
   mView->beginInternal( url );
 
-  QString fileName = KStandardDirs::locate( "data", "khelpcenter/index.html.in" );
+  QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "khelpcenter/index.html.in" );
   if ( fileName.isEmpty() )
     return;
 
@@ -503,7 +533,7 @@ QString Navigator::createChildrenList( QTreeWidgetItem *child )
 void Navigator::slotSearch()
 {
   
-  kDebug(1400) << "Navigator::slotSearch()";
+  qCDebug(category) << "Navigator::slotSearch()";
 
   if ( !checkSearchIndex() ) return;
 
@@ -514,8 +544,8 @@ void Navigator::slotSearch()
   int pages = mSearchWidget->pages();
   QString scope = mSearchWidget->scope();
 
-  kDebug(1400) << "Navigator::slotSearch() words: " << words;
-  kDebug(1400) << "Navigator::slotSearch() scope: " << scope;
+  qCDebug(category) << "Navigator::slotSearch() words: " << words;
+  qCDebug(category) << "Navigator::slotSearch() scope: " << scope;
 
   if ( words.isEmpty() || scope.isEmpty() ) return;
 
@@ -543,7 +573,7 @@ void Navigator::slotSearchFinished()
   mSearchButton->setEnabled(true);
   QApplication::restoreOverrideCursor();
 
-  kDebug( 1400 ) << "Search finished.";
+  qCDebug(category) << "Search finished.";
 }
 
 void Navigator::checkSearchButton()
@@ -562,7 +592,7 @@ void Navigator::hideSearch()
 
 bool Navigator::checkSearchIndex()
 {
-  KConfigGroup cfg(KGlobal::config(), "Search" );
+  KConfigGroup cfg(KSharedConfig::openConfig(), "Search" );
   if ( cfg.readEntry( "IndexExists", false) ) return true;
 
   if ( mIndexDialog && !mIndexDialog->isHidden() ) return true;
@@ -582,9 +612,9 @@ bool Navigator::checkSearchIndex()
   return true;
 }
 
-void Navigator::slotTabChanged( QWidget *wid )
+void Navigator::slotTabChanged( int id )
 {
-  if ( wid == mSearchWidget ) checkSearchIndex();
+  if ( mTabWidget->widget(id) == mSearchWidget ) checkSearchIndex();
 }
 
 void Navigator::slotSelectGlossEntry( const QString &id )
@@ -592,11 +622,11 @@ void Navigator::slotSelectGlossEntry( const QString &id )
   mGlossaryTree->slotSelectGlossEntry( id );
 }
 
-KUrl Navigator::homeURL()
+QUrl Navigator::homeURL()
 {
   if ( !mHomeUrl.isEmpty() ) return mHomeUrl;
 
-  KSharedConfig::Ptr cfg = KGlobal::config();
+  KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
   // We have to reparse the configuration here in order to get a
   // language-specific StartUrl, e.g. "StartUrl[de]".
   cfg->reparseConfiguration();
