@@ -45,8 +45,8 @@
 #include "kio_man.moc"
 #include "man2html.h"
 #include <assert.h>
-#include <kfilterbase.h>
 #include <kfilterdev.h>
+#include <QStandardPaths>
 
 using namespace KIO;
 
@@ -139,8 +139,8 @@ MANProtocol::MANProtocol(const QByteArray &pool_socket, const QByteArray &app_so
     section_names << "0" << "0p" << "1" << "1p" << "2" << "3" << "3n" << "3p" << "4" << "5" << "6" << "7"
                   << "8" << "9" << "l" << "n";
 
-    QString cssPath(KStandardDirs::locate( "data", "kio_docfilter/kio_docfilter.css" ));
-    KUrl cssUrl(KUrl::fromPath(cssPath));
+    QString cssPath(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kio_docfilter/kio_docfilter.css" ));
+    QUrl cssUrl(QUrl::fromLocalFile(cssPath));
     m_manCSSFile = cssUrl.url().toUtf8();
 }
 
@@ -449,7 +449,7 @@ extern void output_real(const char *insert)
 }
 #endif
 
-void MANProtocol::get(const KUrl& url )
+void MANProtocol::get(const QUrl& url )
 {
     kDebug(7107) << "GET " << url.url();
 
@@ -660,7 +660,7 @@ void MANProtocol::outputMatchingPages(const QStringList &matchingPages)
     finished();
 }
 
-void MANProtocol::stat( const KUrl& url)
+void MANProtocol::stat( const QUrl& url)
 {
     kDebug(7107) << "ENTERING STAT " << url.url();
 
@@ -696,7 +696,7 @@ void MANProtocol::stat( const KUrl& url)
 extern "C"
 {
 
-    int KDE_EXPORT kdemain( int argc, char **argv ) {
+    int Q_DECL_EXPORT kdemain( int argc, char **argv ) {
 
         KComponentData componentData("kio_man");
 
@@ -718,7 +718,7 @@ extern "C"
 
 }
 
-void MANProtocol::mimetype(const KUrl & /*url*/)
+void MANProtocol::mimetype(const QUrl & /*url*/)
 {
     mimeType("text/html");
     finished();
@@ -1143,18 +1143,22 @@ int compare_man_index(const void *s1, const void *s2)
 
 void MANProtocol::showIndex(const QString& section)
 {
-    QByteArray array;
-    QTextStream os(&array, QIODevice::WriteOnly);
-    os.setCodec( "UTF-8" );
+    QByteArray array_h;
+    QTextStream os_h(&array_h, QIODevice::WriteOnly);
+    os_h.setCodec( "UTF-8" );
 
     // print header
-    os << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Strict//EN\">" << endl;
-    os << "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">" << endl;
-    os << "<title>" << i18n("UNIX Manual Index") << "</title>" << endl;
+    os_h << "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Strict//EN\">" << endl;
+    os_h << "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">" << endl;
+    os_h << "<title>" << i18n("UNIX Manual Index") << "</title>" << endl;
     if ( !m_manCSSFile.isEmpty() )
-        os << "<link href=\"" << m_manCSSFile << "\" type=\"text/css\" rel=\"stylesheet\">" << endl;
-    os << "</head>" << endl;
-    os << "<body><div class=\"secidxmain\">" << endl;
+        os_h << "<link href=\"" << m_manCSSFile << "\" type=\"text/css\" rel=\"stylesheet\">" << endl;
+    os_h << "</head>" << endl << "<body>" << endl;
+
+    QByteArray array_d;
+    QTextStream os(&array_d, QIODevice::WriteOnly);
+    os.setCodec( "UTF-8" );
+    os << "<div class=\"secidxmain\">" << endl;
     os << "<h1>" << i18n( "Index for Section %1: %2", section, sectionName(section)) << "</h1>" << endl;
 
     // compose list of search paths -------------------------------------------------------------
@@ -1171,7 +1175,7 @@ void MANProtocol::showIndex(const QString& section)
       os << "</div></body></html>" << endl;
 
       infoMessage(QString());
-      data(array);
+      data(array_h + array_d);
       finished();
       return;
     }
@@ -1341,12 +1345,15 @@ void MANProtocol::showIndex(const QString& section)
     // print footer
     os << "</body></html>" << endl;
 
+    // set the links "toolbar" also at the top
+    os_h << indexLine << endl;
+
     infoMessage(QString());
-    data(array);
+    data(array_h + array_d);
     finished();
 }
 
-void MANProtocol::listDir(const KUrl &url)
+void MANProtocol::listDir(const QUrl &url)
 {
     kDebug( 7107 ) << url;
 
@@ -1406,12 +1413,12 @@ void MANProtocol::getProgramPath()
   if (!mySgml2RoffPath.isEmpty())
     return;
 
-  mySgml2RoffPath = KGlobal::dirs()->findExe("sgml2roff");
+  mySgml2RoffPath = KStandardDirs::findExe("sgml2roff");
   if (!mySgml2RoffPath.isEmpty())
     return;
 
   /* sgml2roff isn't found in PATH. Check some possible locations where it may be found. */
-  mySgml2RoffPath = KGlobal::dirs()->findExe("sgml2roff", QString(SGML2ROFF_DIRS));
+  mySgml2RoffPath = KStandardDirs::findExe("sgml2roff", QString(SGML2ROFF_DIRS));
   if (!mySgml2RoffPath.isEmpty())
     return;
 
