@@ -31,23 +31,26 @@
 #include <sys/shm.h>
 #endif
 
+#include <QtWidgets/QApplication>
 #include <QtCore/QBuffer>
 #include <QtCore/QFile>
-#include <QBitmap>
-#include <QImage>
-#include <QPainter>
-#include <QPixmap>
+#include <QtGui/QBitmap>
+#include <QtCore/QCryptographicHash>
+//#include <qcryptographichash.h>
+#include <QtGui/QImage>
+#include <QtGui/QPainter>
+#include <QtGui/QPixmap>
 
-#include <kcodecs.h>
+//#include <kcodecs.h>
 #include <kurl.h>
-#include <kapplication.h>
+//#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
 #include <klibrary.h>
-#include <kdebug.h>
+#include <QDebug>
 #include <kservice.h>
 #include <kservicetype.h>
 #include <kservicetypetrader.h>
@@ -96,14 +99,9 @@
 //                Otherwise, the data returned is the image in PNG format.
 
 using namespace KIO;
+//using namespace KCodecs;
 
-extern "C"
-{
-    KDE_EXPORT int kdemain(int argc, char **argv);
-}
-
-
-int kdemain(int argc, char **argv)
+extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
 {
 #ifdef HAVE_NICE
     nice( 5 );
@@ -119,16 +117,13 @@ int kdemain(int argc, char **argv)
     // need QApplication
     // and HTML previews need even KApplication :(
     putenv(strdup("SESSION_MANAGER="));
-    //KApplication::disableAutoDcopRegistration();
-    KAboutData about("kio_thumbnail", 0, ki18n("kio_thumbmail"), "KDE 4.x.x");
-    KCmdLineArgs::init(&about);
 
-    KApplication app( true);
+    QCoreApplication app( argc, argv);
 #endif
 
 
     if (argc != 4) {
-        kError(7115) << "Usage: kio_thumbnail protocol domain-socket1 domain-socket2" << endl;
+        qCritical() << "Usage: kio_thumbnail protocol domain-socket1 domain-socket2" << endl;
         exit(-1);
     }
 
@@ -138,6 +133,7 @@ int kdemain(int argc, char **argv)
     return 0;
 }
 
+
 ThumbnailProtocol::ThumbnailProtocol(const QByteArray &pool, const QByteArray &app)
     : SlaveBase("thumbnail", pool, app),
       m_iconSize(0),
@@ -152,16 +148,16 @@ ThumbnailProtocol::~ThumbnailProtocol()
     m_creators.clear();
 }
 
-void ThumbnailProtocol::get(const KUrl &url)
+void ThumbnailProtocol::get(const QUrl &url)
 {
     m_mimeType = metaData("mimeType");
-    kDebug(7115) << "Wanting MIME Type:" << m_mimeType;
+    qDebug() << "Wanting MIME Type:" << m_mimeType;
 #ifdef THUMBNAIL_HACK
     // ### HACK
     bool direct=false;
     if (m_mimeType.isEmpty()) {
         QFileInfo info(url.path());
-        kDebug(7115) << "PATH: " << url.path() << "isDir:" << info.isDir();
+        qDebug() << "PATH: " << url.path() << "isDir:" << info.isDir();
         if (!info.exists()) {
             // The file does not exist
             error(KIO::ERR_DOES_NOT_EXIST,url.path());
@@ -175,10 +171,10 @@ void ThumbnailProtocol::get(const KUrl &url)
         if (info.isDir()) {
             m_mimeType = "inode/directory";
         } else {
-            m_mimeType = KMimeType::findByUrl(KUrl(info.filePath()))->name();
+            m_mimeType = KMimeType::findByUrl(QUrl(info.filePath()))->name();
         }
 
-        kDebug(7115) << "Guessing MIME Type:" << m_mimeType;
+        qDebug() << "Guessing MIME Type:" << m_mimeType;
         direct=true; // thumbnail: URL was probably typed in Konqueror
     }
 #endif
@@ -198,7 +194,7 @@ void ThumbnailProtocol::get(const KUrl &url)
     }
 #ifdef THUMBNAIL_HACK
     else if (!m_width || !m_height) {
-        kDebug(7115) << "Guessing height, width, icon size!";
+        qDebug() << "Guessing height, width, icon size!";
         m_width = 128;
         m_height = 128;
         iconSize = 128;
@@ -217,7 +213,7 @@ void ThumbnailProtocol::get(const KUrl &url)
 
     QImage img;
 
-    KConfigGroup group( KGlobal::config(), "PreviewSettings" );
+    KConfigGroup group( KSharedConfig::openConfig(), "PreviewSettings" );
 
     // ### KFMI
     bool kfmiThumb = false;
@@ -229,13 +225,13 @@ void ThumbnailProtocol::get(const KUrl &url)
             service->property("SupportsThumbnail").toBool()) {
             // was:  KFileMetaInfo info(url.path(), m_mimeType, KFileMetaInfo::Thumbnail);
             // but m_mimeType and WhatFlags are now unused in KFileMetaInfo, and not present in the
-            // call that takes a KUrl
+            // call that takes a QUrl
             KFileMetaInfo info(url);
             if (info.isValid()) {
                 KFileMetaInfoItem item = info.item("thumbnail");
                 if (item.isValid() && item.value().type() == QVariant::Image) {
                     img = item.value().value<QImage>();
-                    kDebug(7115) << "using KFMI for the thumbnail\n";
+                    qDebug() << "using KFMI for the thumbnail\n";
                     kfmiThumb = true;
                 }
             }
@@ -257,7 +253,7 @@ void ThumbnailProtocol::get(const KUrl &url)
                 plugin = pluginForMimeType(m_mimeType);
             }
 
-            kDebug(7115) << "Guess plugin: " << plugin;
+            qDebug() << "Guess plugin: " << plugin;
 #endif
             if (plugin.isEmpty()) {
                 error(KIO::ERR_INTERNAL, i18n("No plugin specified."));
@@ -322,7 +318,7 @@ void ThumbnailProtocol::get(const KUrl &url)
 #ifdef THUMBNAIL_HACK
         if (direct) {
             // If thumbnail was called directly from Konqueror, then the image needs to be raw
-            //kDebug(7115) << "RAW IMAGE TO STREAM";
+            //qDebug() << "RAW IMAGE TO STREAM";
             QBuffer buf;
             if (!buf.open(QIODevice::WriteOnly)) {
                 error(KIO::ERR_INTERNAL, i18n("Could not write image."));
@@ -338,7 +334,7 @@ void ThumbnailProtocol::get(const KUrl &url)
         {
             QByteArray imgData;
             QDataStream stream( &imgData, QIODevice::WriteOnly );
-            //kDebug(7115) << "IMAGE TO STREAM";
+            //qDebug() << "IMAGE TO STREAM";
             stream << img;
             mimeType("application/octet-stream");
             data(imgData);
@@ -347,7 +343,7 @@ void ThumbnailProtocol::get(const KUrl &url)
 #ifndef Q_WS_WIN
         QByteArray imgData;
         QDataStream stream( &imgData, QIODevice::WriteOnly );
-        //kDebug(7115) << "IMAGE TO SHMID";
+        //qDebug() << "IMAGE TO SHMID";
         void *shmaddr = shmat(shmid.toInt(), 0, 0);
         if (shmaddr == (void *)-1) {
             error(KIO::ERR_INTERNAL, i18n("Failed to attach to shared memory segment %1", shmid));
@@ -470,12 +466,12 @@ void ThumbnailProtocol::drawPictureFrame(QPainter *painter, const QPoint &center
     painter->drawImage(r.topLeft(), transformed);
 }
 
-QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
+QImage ThumbnailProtocol::thumbForDirectory(const QUrl& directory)
 {
     QImage img;
     if (m_propagationDirectories.isEmpty()) {
         // Directories that the directory preview will be propagated into if there is no direct sub-directories
-        const KConfigGroup globalConfig(KGlobal::config(), "PreviewSettings");
+        const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
         m_propagationDirectories = globalConfig.readEntry("PropagationDirectories", QStringList() << "VIDEO_TS").toSet();
         m_maxFileSize = globalConfig.readEntry("MaximumSize", 5 * 1024 * 1024); // 5 MByte default
     }
@@ -489,9 +485,10 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
     // only as small overlay, use no margins)
 
     //Use the current (custom) folder icon
-    KUrl tempDirectory = directory;
+    QUrl tempDirectory = directory;
     tempDirectory.setScheme("file"); //iconNameForUrl will not work with the "thumbnail:/" scheme
-    QString iconName = KMimeType::iconNameForUrl(tempDirectory, S_IFDIR);
+    //QString iconName = KMimeType::findByUrl(tempDirectory)
+    QString iconName = "plasma"; // FIXME
 
     const QPixmap folder = KIconLoader::global()->loadMimeTypeIcon(iconName,
                                                                    KIconLoader::Desktop,
@@ -630,7 +627,7 @@ QImage ThumbnailProtocol::thumbForDirectory(const KUrl& directory)
             --max;
             dir.next();
             if (m_propagationDirectories.contains(dir.fileName())) {
-                return thumbForDirectory(KUrl(dir.filePath()));
+                return thumbForDirectory(QUrl(dir.filePath()));
             }
         }
 
@@ -689,14 +686,14 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
                                            int segmentWidth, int segmentHeight)
 {
     if (m_enabledPlugins.isEmpty()) {
-        const KConfigGroup globalConfig(KGlobal::config(), "PreviewSettings");
+        const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
         m_enabledPlugins = globalConfig.readEntry("Plugins", QStringList()
                                                              << "imagethumbnail"
                                                              << "jpegthumbnail"
                                                              << "videopreview");
     }
 
-    const KUrl fileName = filePath;
+    const QUrl fileName(filePath);
     const QString subPlugin = pluginForMimeType(KMimeType::findByUrl(fileName)->name());
     if (subPlugin.isEmpty() || !m_enabledPlugins.contains(subPlugin)) {
         return false;
@@ -704,7 +701,7 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
 
     ThumbCreator* subCreator = getThumbCreator(subPlugin);
     if (!subCreator) {
-        // kDebug(7115) << "found no creator for" << dir.filePath();
+        // qDebug() << "found no creator for" << dir.filePath();
         return false;
     }
 
@@ -712,8 +709,10 @@ bool ThumbnailProtocol::createSubThumbnail(QImage& thumbnail, const QString& fil
         // check whether a cached version of the file is available for
         // 128 x 128 or 256 x 256 pixels
         int cacheSize = 0;
-        KMD5 md5(QFile::encodeName(fileName.url()));
-        const QString thumbName = QFile::encodeName(md5.hexDigest()) + ".png";
+        QCryptographicHash md5(QCryptographicHash::Md5);
+        md5.addData(QFile::encodeName(fileName.url()));
+        const QString thumbName = QFile::encodeName(md5.result()) + ".png";
+
         if (m_thumbBasePath.isEmpty()) {
             m_thumbBasePath = QDir::homePath() + "/.thumbnails/";
             KStandardDirs::makeDir(m_thumbBasePath + "normal/", 0700);
