@@ -24,17 +24,17 @@
 #include <kprotocolinfo.h>
 #include <ktemporaryfile.h>
 
-#include <kurl.h>
 #include <klocale.h>
 #include <kio/netaccess.h>
 #include <kio/job.h>
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
-#include <kdebug.h>
+#include <QDebug>
 #include <kcmdlineargs.h>
 #include <kconfiggroup.h>
 
 #include <QDir>
+#include <QUrl>
 #include <QFileInfo>
 #include <QVector>
 #include <kjobuidelegate.h>
@@ -47,6 +47,7 @@
 #include <kstandarddirs.h>
 #include <kio/chmodjob.h>
 #include <kio/directorysizejob.h>
+#include <QStandardPaths>
 
 // There are two ways to test encoding things:
 // * with utf8 filenames
@@ -78,7 +79,7 @@ Q_CONSTRUCTOR_FUNCTION(initLocale)
 
 QString TestTrash::homeTmpDir() const
 {
-    return KGlobal::dirs()->localkdedir() + QString::fromLatin1("testtrash/");
+    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QString::fromLatin1("/testtrash/");
 }
 
 QString TestTrash::readOnlyDirPath() const
@@ -121,8 +122,8 @@ static void removeDirRecursive( const QString& dir )
     if ( QFile::exists( dir ) ) {
 
         // Make it work even with readonly dirs, like trashReadOnlyDirFromHome() creates
-        KUrl u = KUrl::fromPath( dir );
-        //kDebug() << "chmod +0200 on" << u;
+        QUrl u = QUrl::fromLocalFile( dir );
+        //qDebug() << "chmod +0200 on" << u;
         KFileItem fileItem(u, QString::fromLatin1("inode/directory"), KFileItem::Unknown);
         KFileItemList fileItemList;
         fileItemList.append( fileItem );
@@ -131,7 +132,7 @@ static void removeDirRecursive( const QString& dir )
 
         KIO::Job* delJob = KIO::del(u, KIO::HideProgressInfo);
         if (!KIO::NetAccess::synchronousRun(delJob, 0))
-            kFatal() << "Couldn't delete " << dir ;
+            qFatal("Couldn't delete %s", qPrintable(dir));
     }
 }
 
@@ -141,8 +142,8 @@ void TestTrash::initTestCase()
     setenv( "KDE_FORK_SLAVES", "yes", true );
 
 
-    m_trashDir = KGlobal::dirs()->localxdgdatadir() + QString::fromLatin1("Trash");
-    kDebug() << "setup: using trash directory " << m_trashDir;
+    m_trashDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QString::fromLatin1("/Trash");
+    qDebug() << "setup: using trash directory " << m_trashDir;
 
     // Look for another writable partition than $HOME (not mandatory)
     TrashImpl impl;
@@ -168,7 +169,7 @@ void TestTrash::initTestCase()
                 if (topdir == QLatin1String("/tmp/")) {
                     m_tmpIsWritablePartition = true;
                     m_tmpTrashId = it.key();
-                    kDebug() << "/tmp is on its own partition (trashid=" << m_tmpTrashId << "), some tests will be skipped";
+                    qDebug() << "/tmp is on its own partition (trashid=" << m_tmpTrashId << "), some tests will be skipped";
                     removeFile( it.value(), QString::fromLatin1("/info/fileFromOther.trashinfo") );
                     removeFile( it.value(), QString::fromLatin1("/files/fileFromOther") );
                     removeFile( it.value(), QString::fromLatin1("/info/symlinkFromOther.trashinfo") );
@@ -191,7 +192,7 @@ void TestTrash::initTestCase()
             m_otherPartitionTopDir = topdir;
             m_otherPartitionTrashDir = trashdir;
             m_otherPartitionId = *it;
-            kDebug() << "OK, found another writable partition: topDir=" << m_otherPartitionTopDir
+            qDebug() << "OK, found another writable partition: topDir=" << m_otherPartitionTopDir
                       << " trashDir=" << m_otherPartitionTrashDir << " id=" << m_otherPartitionId << endl;
             break;
         }
@@ -199,23 +200,23 @@ void TestTrash::initTestCase()
     // Check that m_trashDir got listed
     QVERIFY( foundTrashDir );
     if ( m_otherPartitionTrashDir.isEmpty() )
-        kWarning() << "No writable partition other than $HOME found, some tests will be skipped" ;
+        qWarning() << "No writable partition other than $HOME found, some tests will be skipped" ;
 
     // Start with a clean base dir
-    kDebug() << "initial cleanup";
+    qDebug() << "initial cleanup";
     removeDirRecursive( homeTmpDir() );
     removeDirRecursive( otherTmpDir() );
 
     QDir dir; // TT: why not a static method?
     bool ok = dir.mkdir( homeTmpDir() );
     if ( !ok )
-        kFatal() << "Couldn't create " << homeTmpDir() ;
+        qFatal("Couldn't create directory: %s", qPrintable(homeTmpDir()));
     ok = dir.mkdir( otherTmpDir() );
     if ( !ok )
-        kFatal() << "Couldn't create " << otherTmpDir() ;
+        qFatal("Couldn't create directory: %s", qPrintable(otherTmpDir()));
 
     // Start with a clean trash too
-    kDebug() << "removing trash dir";
+    qDebug() << "removing trash dir";
     removeDirRecursive( m_trashDir );
 }
 
@@ -229,7 +230,7 @@ void TestTrash::cleanupTestCase()
 
 void TestTrash::urlTestFile()
 {
-    const KUrl url = TrashImpl::makeURL(1, QString::fromLatin1("fileId"), QString());
+    const QUrl url = TrashImpl::makeURL(1, QString::fromLatin1("fileId"), QString());
     QCOMPARE( url.url(), QString::fromLatin1("trash:/1-fileId"));
 
     int trashId;
@@ -244,7 +245,7 @@ void TestTrash::urlTestFile()
 
 void TestTrash::urlTestDirectory()
 {
-    const KUrl url = TrashImpl::makeURL( 1, QString::fromLatin1("fileId"), QString::fromLatin1("subfile") );
+    const QUrl url = TrashImpl::makeURL( 1, QString::fromLatin1("fileId"), QString::fromLatin1("subfile") );
     QCOMPARE( url.url(), QString::fromLatin1( "trash:/1-fileId/subfile" ) );
 
     int trashId;
@@ -259,7 +260,7 @@ void TestTrash::urlTestDirectory()
 
 void TestTrash::urlTestSubDirectory()
 {
-    const KUrl url = TrashImpl::makeURL(1, QString::fromLatin1("fileId"), QString::fromLatin1("subfile/foobar"));
+    const QUrl url = TrashImpl::makeURL(1, QString::fromLatin1("fileId"), QString::fromLatin1("subfile/foobar"));
     QCOMPARE(url.url(), QString::fromLatin1("trash:/1-fileId/subfile/foobar"));
 
     int trashId;
@@ -274,14 +275,14 @@ void TestTrash::urlTestSubDirectory()
 
 static void checkInfoFile( const QString& infoPath, const QString& origFilePath )
 {
-    kDebug() << infoPath;
+    qDebug() << infoPath;
     QFileInfo info( infoPath );
     QVERIFY( info.exists() );
     QVERIFY( info.isFile() );
     KConfig infoFile( info.absoluteFilePath() );
     KConfigGroup group = infoFile.group( "Trash Info" );
     if ( !group.exists() )
-        kFatal() << "no Trash Info group in " << info.absoluteFilePath() ;
+        qFatal("no Trash Info group in %s", qPrintable(info.absoluteFilePath()));
     const QString origPath = group.readEntry( "Path" );
     QVERIFY(!origPath.isEmpty());
     QVERIFY(origPath == QString::fromLatin1(QUrl::toPercentEncoding(origFilePath, "/")));
@@ -299,7 +300,7 @@ static void createTestFile( const QString& path )
 {
     QFile f( path );
     if ( !f.open( QIODevice::WriteOnly ) )
-        kFatal() << "Can't create " << path ;
+        qFatal("Can't create %s", qPrintable(path));
     f.write( "Hello world\n", 12 );
     f.close();
     QVERIFY( QFile::exists( path ) );
@@ -310,18 +311,17 @@ void TestTrash::trashFile( const QString& origFilePath, const QString& fileId )
     // setup
     if ( !QFile::exists( origFilePath ) )
         createTestFile( origFilePath );
-    KUrl u;
-    u.setPath( origFilePath );
+    QUrl u = QUrl::fromLocalFile( origFilePath );
 
     // test
-    KIO::Job* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::Job* job = KIO::move( u, QUrl("trash:/"), KIO::HideProgressInfo );
     QMap<QString, QString> metaData;
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
     if ( !ok )
-        kError() << "moving " << u << " to trash failed with error " << KIO::NetAccess::lastError() << " " << KIO::NetAccess::lastErrorString() << endl;
+        qCritical() << "moving " << u << " to trash failed with error " << KIO::NetAccess::lastError() << " " << KIO::NetAccess::lastErrorString() << endl;
     QVERIFY( ok );
     if (origFilePath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition) {
-        kDebug() << " TESTS SKIPPED";
+        qDebug() << " TESTS SKIPPED";
     } else {
         checkInfoFile(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"), origFilePath);
 
@@ -339,10 +339,10 @@ void TestTrash::trashFile( const QString& origFilePath, const QString& fileId )
     for ( ; it != metaData.constEnd() ; ++it ) {
         if (it.key().startsWith(QLatin1String("trashURL"))) {
             const QString origPath = it.key().mid( 9 );
-            KUrl trashURL( it.value() );
-            kDebug() << trashURL;
+            QUrl trashURL( it.value() );
+            qDebug() << trashURL;
             QVERIFY(!trashURL.isEmpty());
-            QVERIFY(trashURL.protocol() == QLatin1String("trash"));
+            QVERIFY(trashURL.scheme() == QLatin1String("trash"));
             int trashId = 0;
             if (origFilePath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition)
                 trashId = m_tmpTrashId;
@@ -399,7 +399,7 @@ void TestTrash::trashFileFromOther()
 void TestTrash::trashFileIntoOtherPartition()
 {
     if ( m_otherPartitionTrashDir.isEmpty() ) {
-        kDebug() << " - SKIPPED";
+        qDebug() << " - SKIPPED";
         return;
     }
     const QString fileName = QString::fromLatin1("testtrash-file");
@@ -412,11 +412,10 @@ void TestTrash::trashFileIntoOtherPartition()
     // setup
     if ( !QFile::exists( origFilePath ) )
         createTestFile( origFilePath );
-    KUrl u;
-    u.setPath( origFilePath );
+    QUrl u = QUrl::fromLocalFile( origFilePath );
 
     // test
-    KIO::Job* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::Job* job = KIO::move( u, QUrl("trash:/"), KIO::HideProgressInfo );
     QMap<QString, QString> metaData;
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
     QVERIFY( ok );
@@ -436,10 +435,10 @@ void TestTrash::trashFileIntoOtherPartition()
     for ( ; it != metaData.constEnd() ; ++it ) {
         if (it.key().startsWith( QLatin1String("trashURL"))) {
             const QString origPath = it.key().mid( 9 );
-            KUrl trashURL( it.value() );
-            kDebug() << trashURL;
+            QUrl trashURL( it.value() );
+            qDebug() << trashURL;
             QVERIFY( !trashURL.isEmpty() );
-            QVERIFY(trashURL.protocol() == QLatin1String("trash"));
+            QVERIFY(trashURL.scheme() == QLatin1String("trash"));
             QVERIFY(trashURL.path() == QString::fromLatin1("/%1-%2").arg( m_otherPartitionId ).arg(fileId));
             found = true;
         }
@@ -449,14 +448,15 @@ void TestTrash::trashFileIntoOtherPartition()
 
 void TestTrash::trashFileOwnedByRoot()
 {
-    KUrl u( "/etc/passwd" );
+    QUrl u( "file:///etc/passwd" );
     const QString fileId = QString::fromLatin1("passwd");
 
-    KIO::CopyJob* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::CopyJob* job = KIO::move( u, QUrl("trash:/"), KIO::HideProgressInfo );
     job->setUiDelegate(0); // no skip dialog, thanks
     QMap<QString, QString> metaData;
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
     QVERIFY( !ok );
+
     QVERIFY( KIO::NetAccess::lastError() == KIO::ERR_ACCESS_DENIED );
     const QString infoPath(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"));
     QVERIFY( !QFile::exists( infoPath ) );
@@ -473,15 +473,14 @@ void TestTrash::trashSymlink( const QString& origFilePath, const QString& fileId
     const char* target = broken ? "/nonexistent" : "/tmp";
     bool ok = ::symlink( target, QFile::encodeName( origFilePath ) ) == 0;
     QVERIFY( ok );
-    KUrl u;
-    u.setPath( origFilePath );
+    QUrl u = QUrl::fromLocalFile( origFilePath );
 
     // test
-    KIO::Job* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::Job* job = KIO::move( u, QUrl("trash:/"), KIO::HideProgressInfo );
     ok = job->exec();
     QVERIFY( ok );
     if (origFilePath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition) {
-        kDebug() << " TESTS SKIPPED";
+        qDebug() << " TESTS SKIPPED";
         return;
     }
     checkInfoFile(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"), origFilePath);
@@ -512,7 +511,7 @@ void TestTrash::trashBrokenSymlinkFromHome()
 
 void TestTrash::trashDirectory( const QString& origPath, const QString& fileId )
 {
-    kDebug() << fileId;
+    qDebug() << fileId;
     // setup
     if ( !QFileInfo( origPath ).exists() ) {
         QDir dir;
@@ -522,13 +521,13 @@ void TestTrash::trashDirectory( const QString& origPath, const QString& fileId )
     createTestFile(origPath + QString::fromLatin1("/testfile"));
     QVERIFY(QDir().mkdir(origPath + QString::fromLatin1("/subdir")));
     createTestFile(origPath + QString::fromLatin1("/subdir/subfile"));
-    KUrl u; u.setPath( origPath );
+    QUrl u = QUrl::fromLocalFile( origPath );
 
     // test
-    KIO::Job* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::Job* job = KIO::move( u, QUrl("trash:/"), KIO::HideProgressInfo );
     QVERIFY( job->exec() );
     if (origPath.startsWith(QLatin1String("/tmp")) && m_tmpIsWritablePartition) {
-        kDebug() << " TESTS SKIPPED";
+        qDebug() << " TESTS SKIPPED";
         return;
     }
     checkInfoFile(m_trashDir + QString::fromLatin1("/info/") + fileId + QString::fromLatin1(".trashinfo"), origPath);
@@ -583,14 +582,14 @@ void TestTrash::trashDirectoryFromOther()
 
 void TestTrash::tryRenameInsideTrash()
 {
-    kDebug() << " with file_move";
-    KIO::Job* job = KIO::file_move( KUrl("trash:/0-tryRenameInsideTrash"), KUrl("trash:/foobar"), -1, KIO::HideProgressInfo );
+    qDebug() << " with file_move";
+    KIO::Job* job = KIO::file_move( QUrl("trash:/0-tryRenameInsideTrash"), QUrl("trash:/foobar"), -1, KIO::HideProgressInfo );
     bool worked = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( !worked );
     QVERIFY( KIO::NetAccess::lastError() == KIO::ERR_CANNOT_RENAME );
 
-    kDebug() << " with move";
-    job = KIO::move( KUrl("trash:/0-tryRenameInsideTrash"), KUrl("trash:/foobar"), KIO::HideProgressInfo );
+    qDebug() << " with move";
+    job = KIO::move( QUrl("trash:/0-tryRenameInsideTrash"), QUrl("trash:/foobar"), KIO::HideProgressInfo );
     worked = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( !worked );
     QVERIFY( KIO::NetAccess::lastError() == KIO::ERR_CANNOT_RENAME );
@@ -599,7 +598,7 @@ void TestTrash::tryRenameInsideTrash()
 void TestTrash::delRootFile()
 {
     // test deleting a trashed file
-    KIO::Job* delJob = KIO::del(KUrl("trash:/0-fileFromHome"), KIO::HideProgressInfo);
+    KIO::Job* delJob = KIO::del(QUrl("trash:/0-fileFromHome"), KIO::HideProgressInfo);
     bool ok = KIO::NetAccess::synchronousRun(delJob, 0);
     QVERIFY( ok );
 
@@ -616,7 +615,7 @@ void TestTrash::delRootFile()
 void TestTrash::delFileInDirectory()
 {
     // test deleting a file inside a trashed directory -> not allowed
-    KIO::Job* delJob = KIO::del(KUrl("trash:/0-trashDirFromHome/testfile"), KIO::HideProgressInfo);
+    KIO::Job* delJob = KIO::del(QUrl("trash:/0-trashDirFromHome/testfile"), KIO::HideProgressInfo);
     bool ok = KIO::NetAccess::synchronousRun(delJob, 0);
     QVERIFY( !ok );
     QVERIFY( KIO::NetAccess::lastError() == KIO::ERR_ACCESS_DENIED );
@@ -632,7 +631,7 @@ void TestTrash::delFileInDirectory()
 void TestTrash::delDirectory()
 {
     // test deleting a trashed directory
-    KIO::Job* delJob = KIO::del(KUrl("trash:/0-trashDirFromHome"), KIO::HideProgressInfo);
+    KIO::Job* delJob = KIO::del(QUrl("trash:/0-trashDirFromHome"), KIO::HideProgressInfo);
     bool ok = KIO::NetAccess::synchronousRun(delJob, 0);
     QVERIFY( ok );
 
@@ -649,7 +648,7 @@ void TestTrash::delDirectory()
 }
 
 // KIO::NetAccess::stat() doesn't set HideProgressInfo - but it's not much work to do it ourselves:
-static bool MyNetAccess_stat(const KUrl& url, KIO::UDSEntry& entry)
+static bool MyNetAccess_stat(const QUrl& url, KIO::UDSEntry& entry)
 {
     KIO::StatJob * statJob = KIO::stat( url, KIO::HideProgressInfo );
     bool ok = KIO::NetAccess::synchronousRun(statJob, 0);
@@ -657,7 +656,7 @@ static bool MyNetAccess_stat(const KUrl& url, KIO::UDSEntry& entry)
         entry = statJob->statResult();
     return ok;
 }
-static bool MyNetAccess_exists(const KUrl& url)
+static bool MyNetAccess_exists(const QUrl& url)
 {
     KIO::UDSEntry dummy;
     return MyNetAccess_stat(url, dummy);
@@ -665,7 +664,7 @@ static bool MyNetAccess_exists(const KUrl& url)
 
 void TestTrash::statRoot()
 {
-    KUrl url( "trash:/" );
+    QUrl url( "trash:/" );
     KIO::UDSEntry entry;
     bool ok = MyNetAccess_stat( url, entry );
     QVERIFY( ok );
@@ -680,7 +679,7 @@ void TestTrash::statRoot()
 
 void TestTrash::statFileInRoot()
 {
-    KUrl url( "trash:/0-fileFromHome" );
+    QUrl url( "trash:/0-fileFromHome" );
     KIO::UDSEntry entry;
     bool ok = MyNetAccess_stat( url, entry );
     QVERIFY( ok );
@@ -696,7 +695,7 @@ void TestTrash::statFileInRoot()
 
 void TestTrash::statDirectoryInRoot()
 {
-    KUrl url( "trash:/0-trashDirFromHome" );
+    QUrl url( "trash:/0-trashDirFromHome" );
     KIO::UDSEntry entry;
     bool ok = MyNetAccess_stat( url, entry );
     QVERIFY( ok );
@@ -711,7 +710,7 @@ void TestTrash::statDirectoryInRoot()
 
 void TestTrash::statSymlinkInRoot()
 {
-    KUrl url( "trash:/0-symlinkFromHome" );
+    QUrl url( "trash:/0-symlinkFromHome" );
     KIO::UDSEntry entry;
     bool ok = MyNetAccess_stat( url, entry );
     QVERIFY( ok );
@@ -726,7 +725,7 @@ void TestTrash::statSymlinkInRoot()
 
 void TestTrash::statFileInDirectory()
 {
-    KUrl url( "trash:/0-trashDirFromHome/testfile" );
+    QUrl url( "trash:/0-trashDirFromHome/testfile" );
     KIO::UDSEntry entry;
     bool ok = MyNetAccess_stat( url, entry );
     QVERIFY( ok );
@@ -741,16 +740,15 @@ void TestTrash::statFileInDirectory()
 
 void TestTrash::copyFromTrash( const QString& fileId, const QString& destPath, const QString& relativePath )
 {
-    KUrl src(QString::fromLatin1("trash:/0-") + fileId);
+    QUrl src(QString::fromLatin1("trash:/0-") + fileId);
     if ( !relativePath.isEmpty() )
-        src.addPath( relativePath );
-    KUrl dest;
-    dest.setPath( destPath );
+        src.setPath(src.path() + '/' + relativePath);
+    QUrl dest = QUrl::fromLocalFile( destPath );
 
     QVERIFY(MyNetAccess_exists(src));
 
     // A dnd would use copy(), but we use copyAs to ensure the final filename
-    //kDebug() << "copyAs:" << src << " -> " << dest;
+    //qDebug() << "copyAs:" << src << " -> " << dest;
     KIO::Job* job = KIO::copyAs( src, dest, KIO::HideProgressInfo );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( ok );
@@ -801,11 +799,10 @@ void TestTrash::copySymlinkFromTrash()
 
 void TestTrash::moveFromTrash( const QString& fileId, const QString& destPath, const QString& relativePath )
 {
-    KUrl src( QString::fromLatin1("trash:/0-") + fileId );
+    QUrl src( QString::fromLatin1("trash:/0-") + fileId );
     if ( !relativePath.isEmpty() )
-        src.addPath( relativePath );
-    KUrl dest;
-    dest.setPath( destPath );
+        src.setPath(src.path() + '/' + relativePath);
+    QUrl dest = QUrl::fromLocalFile( destPath );
 
     QVERIFY(MyNetAccess_exists(src));
 
@@ -855,7 +852,7 @@ void TestTrash::moveDirectoryFromTrash()
 
 void TestTrash::trashDirectoryOwnedByRoot()
 {
-    KUrl u;
+    QUrl u("file:///");;
     if ( QFile::exists( "/etc/cups" ) )
         u.setPath( "/etc/cups" );
     else if ( QFile::exists( "/boot" ) )
@@ -863,9 +860,9 @@ void TestTrash::trashDirectoryOwnedByRoot()
     else
         u.setPath( "/etc" );
     const QString fileId = u.path();
-    kDebug() << "fileId=" << fileId;
+    qDebug() << "fileId=" << fileId;
 
-    KIO::CopyJob* job = KIO::move( u, KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::CopyJob* job = KIO::move( u, QUrl("trash:/"), KIO::HideProgressInfo );
     job->setUiDelegate(0); // no skip dialog, thanks
     QMap<QString, QString> metaData;
     bool ok = KIO::NetAccess::synchronousRun( job, 0, 0, 0, &metaData );
@@ -893,16 +890,16 @@ void TestTrash::moveSymlinkFromTrash()
 void TestTrash::getFile()
 {
     const QString fileId = "fileFromHome 1";
-    const KUrl url = TrashImpl::makeURL( 0, fileId, QString() );
+    const QUrl url = TrashImpl::makeURL( 0, fileId, QString() );
 
     KTemporaryFile tmpFile;
     QVERIFY(tmpFile.open());
     const QString tmpFilePath = tmpFile.fileName();
 
-    KIO::Job* getJob = KIO::file_copy(url, KUrl(tmpFilePath), -1, KIO::Overwrite | KIO::HideProgressInfo);
+    KIO::Job* getJob = KIO::file_copy(url, QUrl::fromLocalFile(tmpFilePath), -1, KIO::Overwrite | KIO::HideProgressInfo);
     bool ok = KIO::NetAccess::synchronousRun(getJob, 0);
     if (!ok) {
-        kDebug() << getJob->errorString();
+        qDebug() << getJob->errorString();
     }
     QVERIFY( ok );
     // Don't use tmpFile.close()+tmpFile.open() here, the size would still be 0 in the QTemporaryFile object
@@ -917,7 +914,7 @@ void TestTrash::getFile()
 void TestTrash::restoreFile()
 {
     const QString fileId = "fileFromHome 1";
-    const KUrl url = TrashImpl::makeURL( 0, fileId, QString() );
+    const QUrl url = TrashImpl::makeURL( 0, fileId, QString() );
     const QString infoFile( m_trashDir + "/info/" + fileId + ".trashinfo" );
     const QString filesItem( m_trashDir + "/files/" + fileId );
 
@@ -943,7 +940,7 @@ void TestTrash::restoreFileFromSubDir()
     const QString fileId = "trashDirFromHome 1/testfile";
     QVERIFY( !QFile::exists( homeTmpDir() + "trashDirFromHome 1" ) );
 
-    const KUrl url = TrashImpl::makeURL( 0, fileId, QString() );
+    const QUrl url = TrashImpl::makeURL( 0, fileId, QString() );
     const QString infoFile( m_trashDir + "/info/trashDirFromHome 1.trashinfo" );
     const QString filesItem( m_trashDir + "/files/trashDirFromHome 1/testfile" );
 
@@ -972,12 +969,12 @@ void TestTrash::restoreFileToDeletedDirectory()
     removeFile( m_trashDir, "/files/fileFromHome" );
     trashFileFromHome();
     // Delete orig dir
-    KIO::Job* delJob = KIO::del(KUrl(homeTmpDir()), KIO::HideProgressInfo);
+    KIO::Job* delJob = KIO::del(QUrl::fromLocalFile(homeTmpDir()), KIO::HideProgressInfo);
     bool delOK = KIO::NetAccess::synchronousRun(delJob, 0);
     QVERIFY( delOK );
 
     const QString fileId = "fileFromHome";
-    const KUrl url = TrashImpl::makeURL( 0, fileId, QString() );
+    const QUrl url = TrashImpl::makeURL( 0, fileId, QString() );
     const QString infoFile( m_trashDir + "/info/" + fileId + ".trashinfo" );
     const QString filesItem( m_trashDir + "/files/" + fileId );
 
@@ -1006,16 +1003,16 @@ void TestTrash::listRootDir()
     m_entryCount = 0;
     m_listResult.clear();
     m_displayNameListResult.clear();
-    KIO::ListJob* job = KIO::listDir( KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::ListJob* job = KIO::listDir( QUrl("trash:/"), KIO::HideProgressInfo );
     connect( job, SIGNAL( entries( KIO::Job*, const KIO::UDSEntryList& ) ),
              SLOT( slotEntries( KIO::Job*, const KIO::UDSEntryList& ) ) );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( ok );
-    kDebug() << "listDir done - m_entryCount=" << m_entryCount;
+    qDebug() << "listDir done - m_entryCount=" << m_entryCount;
     QVERIFY( m_entryCount > 1 );
 
-    //kDebug() << m_listResult;
-    //kDebug() << m_displayNameListResult;
+    //qDebug() << m_listResult;
+    //qDebug() << m_displayNameListResult;
     QCOMPARE(m_listResult.count( "." ), 1); // found it, and only once
     QCOMPARE(m_displayNameListResult.count( "fileFromHome" ), 1);
     QCOMPARE(m_displayNameListResult.count( "fileFromHome 1" ), 1);
@@ -1026,16 +1023,16 @@ void TestTrash::listRecursiveRootDir()
     m_entryCount = 0;
     m_listResult.clear();
     m_displayNameListResult.clear();
-    KIO::ListJob* job = KIO::listRecursive( KUrl("trash:/"), KIO::HideProgressInfo );
+    KIO::ListJob* job = KIO::listRecursive( QUrl("trash:/"), KIO::HideProgressInfo );
     connect( job, SIGNAL( entries( KIO::Job*, const KIO::UDSEntryList& ) ),
              SLOT( slotEntries( KIO::Job*, const KIO::UDSEntryList& ) ) );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( ok );
-    kDebug() << "listDir done - m_entryCount=" << m_entryCount;
+    qDebug() << "listDir done - m_entryCount=" << m_entryCount;
     QVERIFY( m_entryCount > 1 );
 
-    kDebug() << m_listResult;
-    kDebug() << m_displayNameListResult;
+    qDebug() << m_listResult;
+    qDebug() << m_displayNameListResult;
     QCOMPARE(m_listResult.count( "." ), 1); // found it, and only once
     QCOMPARE(m_listResult.count("0-fileFromHome"), 1);
     QCOMPARE(m_listResult.count("0-fileFromHome 1"), 1);
@@ -1045,6 +1042,7 @@ void TestTrash::listRecursiveRootDir()
     QCOMPARE(m_displayNameListResult.count("fileFromHome 1"), 1);
     QCOMPARE(m_displayNameListResult.count("trashDirFromHome/testfile"), 1);
     QCOMPARE(m_displayNameListResult.count("readonly/readonly_subdir/testfile_in_subdir"), 1);
+    
 }
 
 void TestTrash::listSubDir()
@@ -1052,16 +1050,16 @@ void TestTrash::listSubDir()
     m_entryCount = 0;
     m_listResult.clear();
     m_displayNameListResult.clear();
-    KIO::ListJob* job = KIO::listDir( KUrl("trash:/0-trashDirFromHome"), KIO::HideProgressInfo );
+    KIO::ListJob* job = KIO::listDir( QUrl("trash:/0-trashDirFromHome"), KIO::HideProgressInfo );
     connect( job, SIGNAL( entries( KIO::Job*, const KIO::UDSEntryList& ) ),
              SLOT( slotEntries( KIO::Job*, const KIO::UDSEntryList& ) ) );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( ok );
-    kDebug() << "listDir done - m_entryCount=" << m_entryCount;
+    qDebug() << "listDir done - m_entryCount=" << m_entryCount;
     QCOMPARE(m_entryCount, 3);
 
-    //kDebug() << m_listResult;
-    //kDebug() << m_displayNameListResult;
+    //qDebug() << m_listResult;
+    //qDebug() << m_displayNameListResult;
     QCOMPARE(m_listResult.count( "." ), 1); // found it, and only once
     QCOMPARE(m_listResult.count( "testfile" ), 1); // found it, and only once
     QCOMPARE(m_listResult.count("subdir"), 1);
@@ -1075,10 +1073,10 @@ void TestTrash::slotEntries( KIO::Job*, const KIO::UDSEntryList& lst )
         const KIO::UDSEntry& entry (*it);
         QString name = entry.stringValue(KIO::UDSEntry::UDS_NAME);
         QString displayName = entry.stringValue(KIO::UDSEntry::UDS_DISPLAY_NAME);
-        KUrl url = entry.stringValue( KIO::UDSEntry::UDS_URL );
-        kDebug() << "name" << name << "displayName" << displayName << " UDS_URL=" << url;
+        QUrl url(entry.stringValue( KIO::UDSEntry::UDS_URL ));
+        qDebug() << "name" << name << "displayName" << displayName << " UDS_URL=" << url;
         if ( !url.isEmpty() ) {
-            QVERIFY( url.protocol() == "trash" );
+            QVERIFY( url.scheme() == "trash" );
         }
         m_listResult << name;
         m_displayNameListResult << displayName;
@@ -1102,7 +1100,7 @@ void TestTrash::emptyTrash()
     QByteArray packedArgs;
     QDataStream stream( &packedArgs, QIODevice::WriteOnly );
     stream << (int)1;
-    KIO::Job* job = KIO::special( KUrl( "trash:/" ), packedArgs, KIO::HideProgressInfo );
+    KIO::Job* job = KIO::special( QUrl( "trash:/" ), packedArgs, KIO::HideProgressInfo );
     bool ok = KIO::NetAccess::synchronousRun( job, 0 );
     QVERIFY( ok );
 
@@ -1117,28 +1115,28 @@ void TestTrash::emptyTrash()
     QVERIFY(QDir(m_trashDir + "/files").entryList(QDir::NoDotAndDotDot|QDir::AllEntries).isEmpty());
 
 #else
-    kDebug() << " : SKIPPED";
+    qDebug() << " : SKIPPED";
 #endif
 }
 
 void TestTrash::testTrashSize()
 {
-    KIO::DirectorySizeJob* job = KIO::directorySize(KUrl("trash:/"));
+    KIO::DirectorySizeJob* job = KIO::directorySize(QUrl("trash:/"));
     QVERIFY(job->exec());
     QVERIFY(job->totalSize() < 1000000000 /*1GB*/); // #157023
 }
 
-static void checkIcon( const KUrl& url, const QString& expectedIcon )
+static void checkIcon( const QUrl& url, const QString& expectedIcon )
 {
-    QString icon = KMimeType::iconNameForUrl( url );
+    QString icon = KIO::iconNameForUrl( url );
     QCOMPARE( icon, expectedIcon );
 }
 
 void TestTrash::testIcons()
 {
     QCOMPARE(KProtocolInfo::icon("trash"), QString("user-trash-full") ); // #100321
-    checkIcon( KUrl("trash:/"), "user-trash-full" ); // #100321
-    checkIcon( KUrl("trash:/foo/"), "inode-directory" );
+    checkIcon( QUrl("trash:/"), "user-trash-full" ); // #100321
+    checkIcon( QUrl("trash:/foo/"), "inode-directory" );
 }
 
 QTEST_MAIN(TestTrash) // QT5 TODO: NOGUI
