@@ -25,14 +25,15 @@
 
 #include <klocale.h>
 #include <kde_file.h>
+ #include <KLocalizedString>
 #include <kio/global.h>
 #include <kio/renamedialog.h>
 #include <kio/job.h>
 #include <kio/chmodjob.h>
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
-#include <kdebug.h>
-#include <kurl.h>
+#include <qdebug.h>
+#include <QUrl>
 #include <kdirnotify.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
@@ -58,6 +59,7 @@
 #include <solid/device.h>
 #include <solid/block.h>
 #include <solid/storageaccess.h>
+#include <QStandardPaths>
 
 TrashImpl::TrashImpl() :
     QObject(),
@@ -73,7 +75,7 @@ TrashImpl::TrashImpl() :
     if ( KDE_lstat( QFile::encodeName( QDir::homePath() ), &buff ) == 0 ) {
         m_homeDevice = buff.st_dev;
     } else {
-        kError() << "Should never happen: couldn't stat $HOME " << strerror( errno ) << endl;
+        qDebug() << "Should never happen: couldn't stat $HOME " << strerror( errno ) << endl;
     }
 }
 
@@ -118,10 +120,10 @@ int TrashImpl::testDir( const QString &_name ) const
     if ( !ok )
     {
         //KMessageBox::sorry( 0, i18n( "Could not create directory %1. Check for permissions." ).arg( name ) );
-        kWarning() << "could not create" << name ;
+        qWarning() << "could not create" << name ;
         return KIO::ERR_COULD_NOT_MKDIR;
     } else {
-        kDebug() << name << "created.";
+        qDebug() << name << "created.";
     }
   }
   else // exists already
@@ -142,9 +144,9 @@ bool TrashImpl::init()
     // see also kdesktop/init.cc for first time initialization
     m_initStatus = InitError;
     // $XDG_DATA_HOME/Trash, i.e. ~/.local/share/Trash by default.
-    const QString xdgDataDir = KGlobal::dirs()->localxdgdatadir();
-    if ( !KStandardDirs::makeDir( xdgDataDir, 0700 ) ) {
-        kWarning() << "failed to create " << xdgDataDir ;
+    const QString xdgDataDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/');
+   if ( !QDir().mkpath( xdgDataDir ) ) {
+        qWarning() << "failed to create " << xdgDataDir ;
         return false;
     }
 
@@ -164,15 +166,15 @@ bool TrashImpl::init()
     }
     m_trashDirectories.insert( 0, trashDir );
     m_initStatus = InitOK;
-    kDebug() << "initialization OK, home trash dir: " << trashDir;
+    qDebug() << "initialization OK, home trash dir: " << trashDir;
     return true;
 }
 
 void TrashImpl::migrateOldTrash()
 {
-    kDebug() ;
+    qDebug() ;
 
-    KConfigGroup g( KGlobal::config(), "Paths" );
+    KConfigGroup g( KSharedConfig::openConfig(), "Paths" );
     const QString oldTrashDir = g.readPathEntry( "Trash", QString() );
 
     if ( oldTrashDir.isEmpty() )
@@ -190,29 +192,29 @@ void TrashImpl::migrateOldTrash()
         int trashId;
         QString fileId;
         if ( !createInfo( srcPath, trashId, fileId ) ) {
-            kWarning() << "Trash migration: failed to create info for " << srcPath ;
+            qWarning() << "Trash migration: failed to create info for " << srcPath ;
             allOK = false;
         } else {
             bool ok = moveToTrash( srcPath, trashId, fileId );
             if ( !ok ) {
                 (void)deleteInfo( trashId, fileId );
-                kWarning() << "Trash migration: failed to create info for " << srcPath ;
+                qWarning() << "Trash migration: failed to create info for " << srcPath ;
                 allOK = false;
             } else {
-                kDebug() << "Trash migration: moved " << srcPath;
+                qDebug() << "Trash migration: moved " << srcPath;
             }
         }
     }
     if ( allOK ) {
         // We need to remove the old one, otherwise the desktop will have two trashcans...
-        kDebug() << "Trash migration: all OK, removing old trash directory";
+        qDebug() << "Trash migration: all OK, removing old trash directory";
         synchronousDel( oldTrashDir, false, true );
     }
 }
 
 bool TrashImpl::createInfo( const QString& origPath, int& trashId, QString& fileId )
 {
-    kDebug() << origPath;
+    qDebug() << origPath;
     // Check source
     const QByteArray origPath_c( QFile::encodeName( origPath ) );
     /*
@@ -234,28 +236,29 @@ bool TrashImpl::createInfo( const QString& origPath, int& trashId, QString& file
     // Choose destination trash
     trashId = findTrashDirectory( origPath );
     if ( trashId < 0 ) {
-        kWarning() << "OUCH - internal error, TrashImpl::findTrashDirectory returned " << trashId ;
+        qWarning() << "OUCH - internal error, TrashImpl::findTrashDirectory returned " << trashId ;
         return false; // ### error() needed?
     }
-    kDebug() << "trashing to " << trashId;
+    qDebug() << "trashing to " << trashId;
 
     // Grab original filename
-    KUrl url;
-    url.setPath( origPath );
+    QUrl url = QUrl::fromLocalFile( origPath );
     const QString origFileName = url.fileName();
 
     // Make destination file in info/
     url.setPath( infoPath( trashId, origFileName ) ); // we first try with origFileName
-    KUrl baseDirectory;
-    baseDirectory.setPath( url.directory() );
+    QUrl baseDirectory = QUrl::fromLocalFile( url.path() );
     // Here we need to use O_EXCL to avoid race conditions with other kioslave processes
     int fd = 0;
+    QString fileName;
     do {
-        kDebug() << "trying to create " << url.path() ;
+        qDebug() << "trying to create " << url.path() ;
         fd = KDE_open( QFile::encodeName( url.path() ), O_WRONLY | O_CREAT | O_EXCL, 0600 );
         if ( fd < 0 ) {
-            if ( errno == EEXIST ) {
-                url.setFileName( KIO::RenameDialog::suggestName( baseDirectory, url.fileName() ) );
+            if (errno == EEXIST ) {
+                fileName = url.fileName();
+                url = url.adjusted(QUrl::RemoveFilename);
+                url.setPath(url.path() + KIO::RenameDialog::suggestName( baseDirectory,  fileName)  );
                 // and try again on the next iteration
             } else {
                 error( KIO::ERR_COULD_NOT_WRITE, url.path() );
@@ -300,7 +303,7 @@ bool TrashImpl::createInfo( const QString& origPath, int& trashId, QString& file
 
     ::fclose( file );
 
-    kDebug() << "info file created in trashId=" << trashId << " : " << fileId;
+    qDebug() << "info file created in trashId=" << trashId << " : " << fileId;
     return true;
 }
 
@@ -317,7 +320,7 @@ QString TrashImpl::makeRelativePath( const QString& topdir, const QString& path
         Q_ASSERT( rel[0] != QLatin1Char('/') );
         return rel;
     } else { // shouldn't happen...
-        kWarning() << "Couldn't make relative path for " << realPath << " (" << path << "), with topdir=" << topdir ;
+        qWarning() << "Couldn't make relative path for " << realPath << " (" << path << "), with topdir=" << topdir ;
         return realPath;
     }
 }
@@ -357,7 +360,7 @@ bool TrashImpl::deleteInfo( int trashId, const QString& fileId )
 
 bool TrashImpl::moveToTrash( const QString& origPath, int trashId, const QString& fileId )
 {
-    kDebug() ;
+    qDebug() <<"Trashing" << origPath<<trashId<<fileId;
     if ( !adaptTrashSize( origPath, trashId ) )
         return false;
 
@@ -408,16 +411,16 @@ bool TrashImpl::move( const QString& src, const QString& dest )
     if ( directRename( src, dest ) ) {
         // This notification is done by KIO::moveAs when using the code below
         // But if we do a direct rename we need to do the notification ourselves
-        org::kde::KDirNotify::emitFilesAdded( dest );
+        org::kde::KDirNotify::emitFilesAdded( QUrl::fromLocalFile(dest) );
         return true;
     }
     if ( m_lastErrorCode != KIO::ERR_UNSUPPORTED_ACTION )
         return false;
 
-    KUrl urlSrc, urlDest;
-    urlSrc.setPath( src );
-    urlDest.setPath( dest );
-    kDebug() << urlSrc << " -> " << urlDest;
+    QUrl urlSrc = QUrl::fromLocalFile(src);
+    QUrl urlDest = QUrl::fromLocalFile(dest);
+
+    qDebug() << urlSrc << " -> " << urlDest;
     KIO::CopyJob* job = KIO::moveAs( urlSrc, urlDest, KIO::HideProgressInfo );
     job->setUiDelegate(0);
     connect( job, SIGNAL( result(KJob*) ),
@@ -429,14 +432,15 @@ bool TrashImpl::move( const QString& src, const QString& dest )
 
 void TrashImpl::jobFinished(KJob* job)
 {
-    kDebug() << " error=" << job->error();
+    qDebug() << " error=" << job->error() << job->errorText();
     error( job->error(), job->errorText() );
+
     emit leaveModality();
 }
 
 bool TrashImpl::copyToTrash( const QString& origPath, int trashId, const QString& fileId )
 {
-    kDebug() ;
+    qDebug() ;
     if ( !adaptTrashSize( origPath, trashId ) )
         return false;
 
@@ -469,11 +473,9 @@ bool TrashImpl::copy( const QString& src, const QString& dest )
 {
     // kio_file's copy() method is quite complex (in order to be fast), let's just call it...
     m_lastErrorCode = 0;
-    KUrl urlSrc;
-    urlSrc.setPath( src );
-    KUrl urlDest;
-    urlDest.setPath( dest );
-    kDebug() << "copying " << src << " to " << dest;
+    QUrl urlSrc = QUrl::fromLocalFile( src );
+    QUrl urlDest = QUrl::fromLocalFile( dest );
+    qDebug() << "copying " << src << " to " << dest;
     KIO::CopyJob* job = KIO::copyAs( urlSrc, urlDest, KIO::HideProgressInfo );
     job->setUiDelegate(0);
     connect( job, SIGNAL( result(KJob*) ),
@@ -485,7 +487,7 @@ bool TrashImpl::copy( const QString& src, const QString& dest )
 
 bool TrashImpl::directRename( const QString& src, const QString& dest )
 {
-    kDebug() << src << " -> " << dest;
+    qDebug() << src << " -> " << dest;
     if ( KDE_rename( QFile::encodeName( src ), QFile::encodeName( dest ) ) != 0 ) {
         if (errno == EXDEV) {
             error( KIO::ERR_UNSUPPORTED_ACTION, QString::fromLatin1("rename") );
@@ -561,12 +563,11 @@ bool TrashImpl::synchronousDel( const QString& path, bool setLastErrorCode, bool
 {
     const int oldErrorCode = m_lastErrorCode;
     const QString oldErrorMsg = m_lastErrorMessage;
-    KUrl url;
-    url.setPath( path );
+    QUrl url = QUrl::fromLocalFile( path );
     // First ensure that all dirs have u+w permissions,
     // otherwise we won't be able to delete files in them (#130780).
     if ( isDir ) {
-        kDebug() << "chmod'ing " << url;
+       qDebug() << "chmod'ing " << url;
         KFileItem fileItem( url, QString::fromLatin1("inode/directory"), KFileItem::Unknown );
         KFileItemList fileItemList;
         fileItemList.append( fileItem );
@@ -590,7 +591,7 @@ bool TrashImpl::synchronousDel( const QString& path, bool setLastErrorCode, bool
 
 bool TrashImpl::emptyTrash()
 {
-    kDebug() ;
+    qDebug() ;
     // The naive implementation "delete info and files in every trash directory"
     // breaks when deleted directories contain files owned by other users.
     // We need to ensure that the .trashinfo file is only removed when the
@@ -619,7 +620,7 @@ bool TrashImpl::emptyTrash()
             myErrorMsg = m_lastErrorMessage;
             // and remember not to remove this file
             unremoveableFiles.insert(filesPath);
-            kDebug() << "Unremoveable:" << filesPath;
+            qDebug() << "Unremoveable:" << filesPath;
         }
 
         TrashSizeCache trashSize( trashDirectoryPath( info.trashId ) );
@@ -637,7 +638,7 @@ bool TrashImpl::emptyTrash()
                 continue;
             const QString filePath = filesDir + QLatin1Char('/') + fileName;
             if (!unremoveableFiles.contains(filePath)) {
-                kWarning() << "Removing orphaned file" << filePath;
+                qWarning() << "Removing orphaned file" << filePath;
                 QFile::remove(filePath);
             }
         }
@@ -677,7 +678,7 @@ TrashImpl::TrashedFileInfoList TrashImpl::list()
             if ( fileName == QLatin1String(".") || fileName == QLatin1String("..") )
                 continue;
             if ( !fileName.endsWith( QLatin1String(".trashinfo") ) ) {
-                kWarning() << "Invalid info file found in " << infoPath << " : " << fileName ;
+                qWarning() << "Invalid info file found in " << infoPath << " : " << fileName ;
                 continue;
             }
             fileName.truncate( fileName.length() - 10 );
@@ -699,7 +700,7 @@ QStringList TrashImpl::listDir( const QString& physicalPath )
 
 bool TrashImpl::infoForFile( int trashId, const QString& fileId, TrashedFileInfo& info )
 {
-    kDebug() << trashId << " " << fileId;
+    qDebug() << trashId << " " << fileId;
     info.trashId = trashId; // easy :)
     info.fileId = fileId; // equally easy
     info.physicalPath = filesPath( trashId, fileId );
@@ -743,7 +744,7 @@ QString TrashImpl::physicalPath( int trashId, const QString& fileId, const QStri
 void TrashImpl::error( int e, const QString& s )
 {
     if ( e )
-        kDebug() << e << " " << s;
+        qDebug() << e << " " << s;
     m_lastErrorCode = e;
     m_lastErrorMessage = s;
 }
@@ -767,7 +768,7 @@ bool TrashImpl::isEmpty() const
             ep = KDE_readdir( dp ); // look for third file
             closedir( dp );
             if ( ep != 0 ) {
-                //kDebug() << ep->d_name << " in " << infoPath << " -> not empty";
+                //qDebug() << ep->d_name << " in " << infoPath << " -> not empty";
                 return false; // not empty
             }
         }
@@ -804,7 +805,7 @@ static int idForDevice(const Solid::Device& device)
 {
     const Solid::Block* block = device.as<Solid::Block>();
     if (block) {
-        kDebug() << "major=" << block->deviceMajor() << " minor=" << block->deviceMinor();
+        qDebug() << "major=" << block->deviceMajor() << " minor=" << block->deviceMinor();
         return block->deviceMajor()*1000 + block->deviceMinor();
     } else {
         // Not a block device. Maybe a NFS mount?
@@ -814,7 +815,7 @@ static int idForDevice(const Solid::Device& device)
 
 int TrashImpl::findTrashDirectory( const QString& origPath )
 {
-    kDebug() << origPath;
+    qDebug() << origPath;
     // First check if same device as $HOME, then we use the home trash right away.
     KDE_struct_stat buff;
     if ( KDE_lstat( QFile::encodeName( origPath ), &buff ) == 0
@@ -823,24 +824,24 @@ int TrashImpl::findTrashDirectory( const QString& origPath )
 
     KMountPoint::Ptr mp = KMountPoint::currentMountPoints().findByPath( origPath );
     if (!mp) {
-        kDebug() << "KMountPoint found no mount point for" << origPath;
+        qDebug() << "KMountPoint found no mount point for" << origPath;
         return 0;
     }
     QString mountPoint = mp->mountPoint();
     const QString trashDir = trashForMountPoint( mountPoint, true );
-    kDebug() << "mountPoint=" << mountPoint << " trashDir=" << trashDir;
+    qDebug() << "mountPoint=" << mountPoint << " trashDir=" << trashDir;
     if ( trashDir.isEmpty() )
         return 0; // no trash available on partition
     int id = idForTrashDirectory( trashDir );
     if ( id > -1 ) {
-        kDebug() << " known with id " << id;
+        qDebug() << " known with id " << id;
         return id;
     }
     // new trash dir found, register it
     // but we need stability in the trash IDs, so that restoring or asking
     // for properties works even kio_trash gets killed because idle.
 #if 0
-    kDebug() << "found " << trashDir;
+    qDebug() << "found " << trashDir;
     m_trashDirectories.insert( ++m_lastId, trashDir );
     if ( !mountPoint.endsWith( '/' ) )
         mountPoint += '/';
@@ -849,9 +850,9 @@ int TrashImpl::findTrashDirectory( const QString& origPath )
 #endif
 
     const QString query = QString::fromLatin1("[StorageAccess.accessible == true AND StorageAccess.filePath == '")+mountPoint+QString::fromLatin1("']");
-    //kDebug() << "doing solid query:" << query;
+    //qDebug() << "doing solid query:" << query;
     const QList<Solid::Device> lst = Solid::Device::listFromQuery(query);
-    //kDebug() << "got" << lst.count() << "devices";
+    //qDebug() << "got" << lst.count() << "devices";
     if ( lst.isEmpty() ) // not a device. Maybe some tmpfs mount for instance.
         return 0; // use the home trash instead
     // Pretend we got exactly one...
@@ -863,7 +864,7 @@ int TrashImpl::findTrashDirectory( const QString& origPath )
         return 0;
     }
     m_trashDirectories.insert( id, trashDir );
-    kDebug() << "found" << trashDir << "gave it id" << id;
+    qDebug() << "found" << trashDir << "gave it id" << id;
     if (!mountPoint.endsWith(QLatin1Char('/')))
         mountPoint += QLatin1Char('/');
     m_topDirectories.insert( id, mountPoint );
@@ -887,7 +888,7 @@ void TrashImpl::scanTrashDirectories() const
                     continue;
                 }
                 m_trashDirectories.insert( trashId, trashDir );
-                kDebug() << "found " << trashDir << " gave it id " << trashId;
+                qDebug() << "found " << trashDir << " gave it id " << trashId;
                 if (!topdir.endsWith(QLatin1Char('/')))
                     topdir += QLatin1Char('/');
                 m_topDirectories.insert( trashId, topdir );
@@ -936,13 +937,13 @@ QString TrashImpl::trashForMountPoint( const QString& topdir, bool createIfNeede
                      && (buff.st_mode & 0777) == 0700 ) { // rwx for user
                     return trashDir;
                 }
-                kDebug() << "Directory " << trashDir << " exists but didn't pass the security checks, can't use it";
+                qDebug() << "Directory " << trashDir << " exists but didn't pass the security checks, can't use it";
             }
             else if ( createIfNeeded && initTrashDirectory( trashDir_c ) ) {
                 return trashDir;
             }
         } else {
-            kDebug() << "Root trash dir " << rootTrashDir << " exists but didn't pass the security checks, can't use it";
+            qDebug() << "Root trash dir " << rootTrashDir << " exists but didn't pass the security checks, can't use it";
         }
     }
 
@@ -959,7 +960,7 @@ QString TrashImpl::trashForMountPoint( const QString& topdir, bool createIfNeede
             if ( checkTrashSubdirs( trashDir_c ) )
                 return trashDir;
         }
-        kDebug() << "Directory " << trashDir << " exists but didn't pass the security checks, can't use it";
+        qDebug() << "Directory " << trashDir << " exists but didn't pass the security checks, can't use it";
         // Exists, but not useable
         return QString();
     }
@@ -983,10 +984,10 @@ int TrashImpl::idForTrashDirectory( const QString& trashDir ) const
 
 bool TrashImpl::initTrashDirectory( const QByteArray& trashDir_c ) const
 {
-    kDebug() << trashDir_c;
+    qDebug() << trashDir_c;
     if ( KDE_mkdir( trashDir_c, 0700 ) != 0 )
         return false;
-    kDebug() ;
+    qDebug() ;
     // This trash dir will be useable only if the directory is owned by user.
     // In theory this is the case, but not on e.g. USB keys...
     uid_t uid = getuid();
@@ -999,7 +1000,7 @@ bool TrashImpl::initTrashDirectory( const QByteArray& trashDir_c ) const
         return checkTrashSubdirs( trashDir_c );
 
     } else {
-        kDebug() << trashDir_c << " just created, by it doesn't have the right permissions, probably some strange unsupported filesystem";
+        qDebug() << trashDir_c << " just created, by it doesn't have the right permissions, probably some strange unsupported filesystem";
         ::rmdir( trashDir_c );
         return false;
     }
@@ -1040,10 +1041,10 @@ QString TrashImpl::topDirectoryPath( int trashId ) const
 
 // Helper method. Creates a URL with the format trash:/trashid-fileid or
 // trash:/trashid-fileid/relativePath/To/File for a file inside a trashed directory.
-KUrl TrashImpl::makeURL( int trashId, const QString& fileId, const QString& relativePath )
+QUrl TrashImpl::makeURL( int trashId, const QString& fileId, const QString& relativePath )
 {
-    KUrl url;
-    url.setProtocol(QString::fromLatin1("trash"));
+    QUrl url;
+    url.setScheme(QString::fromLatin1("trash"));
     QString path = QString::fromLatin1("/");
     path += QString::number( trashId );
     path += QLatin1Char('-');
@@ -1058,14 +1059,11 @@ KUrl TrashImpl::makeURL( int trashId, const QString& fileId, const QString& rela
 
 // Helper method. Parses a trash URL with the URL scheme defined in makeURL.
 // The trash:/ URL itself isn't parsed here, must be caught by the caller before hand.
-bool TrashImpl::parseURL( const KUrl& url, int& trashId, QString& fileId, QString& relativePath )
+bool TrashImpl::parseURL( const QUrl& url, int& trashId, QString& fileId, QString& relativePath )
 {
-    if (url.protocol() != QLatin1String("trash"))
+    if (url.scheme() != QLatin1String("trash"))
         return false;
     const QString path = url.path();
-    if (path.isEmpty()) {
-        return false;
-    }
     int start = 0;
     if ( path[0] == QLatin1Char('/') ) // always true I hope
         start = 1;
@@ -1170,4 +1168,4 @@ bool TrashImpl::adaptTrashSize( const QString& origPath, int trashId )
     return true;
 }
 
-#include "trashimpl.moc"
+#include "moc_trashimpl.cpp"
