@@ -41,16 +41,16 @@ K_PLUGIN_FACTORY(DeviceAutomounterKCMFactory, registerPlugin<DeviceAutomounterKC
 K_EXPORT_PLUGIN(DeviceAutomounterKCMFactory("kcm_device_automounter"))
 
 DeviceAutomounterKCM::DeviceAutomounterKCM(QWidget *parent, const QVariantList &)
-    : KCModule(DeviceAutomounterKCMFactory::componentData(), parent)
+    : KCModule(parent)
 {
     KAboutData *about = new KAboutData("kcm_device_automounter",
                                        0,
-                                       ki18n("Device Automounter"),
+                                       i18n("Device Automounter"),
                                        "0.1",
-                                       ki18n("Automatically mounts devices at login or when attached"),
+                                       i18n("Automatically mounts devices at login or when attached"),
                                        KAboutData::License_GPL_V2,
-                                       ki18n("(c) 2009 Trever Fischer"));
-    about->addAuthor(ki18n("Trever Fischer"));
+                                       i18n("(c) 2009 Trever Fischer"));
+    about->addAuthor(i18n("Trever Fischer"));
 
     setAboutData(about);
     setupUi(this);
@@ -237,3 +237,6 @@ DeviceAutomounterKCM::loadLayout()
     deviceView->setExpanded(m_devices->index(0,0), LayoutSettings::attachedExpanded());
     deviceView->setExpanded(m_devices->index(1,0), LayoutSettings::detatchedExpanded());
 }
+
+#include "moc_DeviceAutomounterKCM.cpp"
+#include "DeviceAutomounterKCM.moc"
